import {
    AsaliError
} from "./utils.js"

let transportDict = {
    "AC3H4": [
        1,
        252,
        4.76,
        0,
        0,
        0,
        40.0648
    ],
    "CH3COOH": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        60.0526
    ],
    "CH3COCH3": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        58.08
    ],
    "C2H3CHO": [
        2,
        443.2,
        4.12,
        0,
        0,
        1,
        56.0642
    ],
    "C2H5CHO": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        58.08
    ],
    "C4H9CHO": [
        2,
        500,
        5.64,
        0,
        0,
        1,
        86.1338
    ],
    "CH2CHCH2": [
        2,
        316,
        4.22,
        0,
        0,
        1,
        41.0727
    ],
    "CHCHCH3": [
        2,
        316,
        4.22,
        0,
        0,
        1,
        41.0727
    ],
    "CH2CCH3": [
        2,
        316,
        4.22,
        0,
        0,
        1,
        41.0727
    ],
    "AR": [
        0,
        136.5,
        3.33,
        0,
        0,
        0,
        39.948
    ],
    "C6H5CH2OH": [
        2,
        622.4,
        5.53,
        0,
        0,
        1,
        108.14
    ],
    "C6H4O2": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        108.097
    ],
    "C6H6": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        78.1136
    ],
    "C6H5CHO": [
        2,
        622.4,
        5.53,
        0,
        0,
        1,
        106.124
    ],
    "C6H5C2H4C6H5": [
        2,
        783.8,
        6.64,
        0,
        0,
        1,
        182.265
    ],
    "NC4H8": [
        2,
        355,
        4.65,
        0,
        0,
        1,
        56.1075
    ],
    "C4H6": [
        2,
        357,
        5.18,
        0,
        0,
        1,
        54.0916
    ],
    "C": [
        0,
        71.4,
        3.298,
        0,
        0,
        0,
        12.011
    ],
    "C12H8": [
        2,
        689.8,
        6.5,
        0,
        0,
        1,
        152.196
    ],
    "C2H": [
        1,
        209,
        4.1,
        0,
        0,
        2.5,
        25.0299
    ],
    "C2H2": [
        1,
        209,
        4.1,
        0,
        0,
        2.5,
        26.0379
    ],
    "C2H4": [
        2,
        280.8,
        3.971,
        0,
        0,
        1.5,
        28.0538
    ],
    "C2H5": [
        2,
        252.3,
        4.302,
        0,
        0,
        1.5,
        29.0617
    ],
    "C2H6": [
        2,
        252.3,
        4.302,
        0,
        0,
        1.5,
        30.0696
    ],
    "C3H2": [
        2,
        209,
        4.1,
        0,
        0,
        1,
        38.0489
    ],
    "C3H3": [
        2,
        252,
        4.76,
        0,
        0,
        1,
        39.0568
    ],
    "C3H6": [
        2,
        307.8,
        4.14,
        0,
        0,
        1,
        42.0806
    ],
    "C3H8": [
        2,
        303.4,
        4.81,
        0,
        0,
        1,
        44.0965
    ],
    "NC3H7O": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        59.088
    ],
    "C3H7OOH": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        76.0953
    ],
    "C4H2": [
        1,
        357,
        5.18,
        0,
        0,
        1,
        50.0599
    ],
    "C4H3": [
        1,
        357,
        5.18,
        0,
        0,
        1,
        51.0678
    ],
    "C4H4": [
        2,
        357,
        5.18,
        0,
        0,
        1,
        52.0758
    ],
    "C4H5": [
        2,
        357,
        5.18,
        0,
        0,
        1,
        53.0837
    ],
    "CH2C3H5": [
        2,
        355,
        4.65,
        0,
        0,
        1,
        55.0996
    ],
    "SC4H7": [
        2,
        355,
        4.65,
        0,
        0,
        1,
        55.0996
    ],
    "C4H9OOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        90.1222
    ],
    "CYC5H4O": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        80.0862
    ],
    "C5H7": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        67.1106
    ],
    "NC5H11OOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        104.149
    ],
    "C6H5": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        77.1057
    ],
    "C6H5O": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        93.1051
    ],
    "LC6H6": [
        2,
        412.3,
        5.349,
        0,
        0,
        1,
        78.1136
    ],
    "CYC6H10-ONE": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        98.1448
    ],
    "C7H7": [
        2,
        495.3,
        5.68,
        0,
        0,
        1,
        91.1326
    ],
    "NC7H15OOH": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        132.203
    ],
    "CYC5H8": [
        1,
        408,
        5.2,
        0,
        0,
        1,
        68.1185
    ],
    "CYC6H8": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        80.1295
    ],
    "CYC6H12": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        84.1613
    ],
    "CYC6H10": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        82.1454
    ],
    "CH": [
        1,
        80,
        2.75,
        0,
        0,
        0,
        13.0189
    ],
    "CH2": [
        1,
        144,
        3.8,
        0,
        0,
        0,
        14.0269
    ],
    "CH2CO": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        42.0373
    ],
    "CH2O": [
        2,
        498,
        3.59,
        0,
        0,
        2,
        30.0263
    ],
    "CH2OH": [
        2,
        417,
        3.69,
        1.7,
        0,
        2,
        31.0342
    ],
    "CH2S": [
        1,
        144,
        3.8,
        0,
        0,
        0,
        14.0269
    ],
    "CH3": [
        1,
        144,
        3.8,
        0,
        0,
        0,
        15.0348
    ],
    "CH3CO": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        43.0452
    ],
    "CH3O": [
        2,
        417,
        3.69,
        1.7,
        0,
        2,
        31.0342
    ],
    "CH3OH": [
        2,
        481.8,
        3.626,
        0,
        0,
        1,
        32.0422
    ],
    "CH4": [
        2,
        141.4,
        3.746,
        0,
        2.6,
        13,
        16.0428
    ],
    "CO": [
        1,
        98.1,
        3.65,
        0,
        1.95,
        1.8,
        28.0104
    ],
    "CO2": [
        1,
        244,
        3.763,
        0,
        2.65,
        2.1,
        44.0098
    ],
    "CYC5H6": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        66.1026
    ],
    "MCPTD": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        80.1295
    ],
    "CRESOL": [
        2,
        621.1,
        5.64,
        0,
        0,
        1,
        108.14
    ],
    "NC10H20": [
        2,
        540.98,
        7.15,
        0,
        0,
        1,
        140.269
    ],
    "C6H5CH2C6H5": [
        2,
        712.6,
        6.89,
        0,
        0,
        1,
        168.238
    ],
    "DIPE": [
        2,
        432,
        6,
        0,
        0,
        1,
        102.177
    ],
    "MTBE-O": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        102.133
    ],
    "CH3OCH3": [
        2,
        303.4,
        4.81,
        0,
        0,
        1,
        46.069
    ],
    "CH3CH3-C5H6": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        96.1723
    ],
    "C6H5C2H5": [
        2,
        523.6,
        5.96,
        0,
        0,
        1,
        106.167
    ],
    "NC7H14": [
        2,
        459.98,
        6.31,
        0,
        0,
        1,
        98.1882
    ],
    "NC6H12": [
        2,
        412.3,
        5.349,
        0,
        0,
        1,
        84.1613
    ],
    "C5H9CHO": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        98.1448
    ],
    "ETBE": [
        2,
        432,
        6,
        0,
        0,
        1,
        102.177
    ],
    "NEOC5H10-O": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        86.1338
    ],
    "C4H8O": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        72.1069
    ],
    "NC5H10-O": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        86.1338
    ],
    "NC7H14O": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        114.188
    ],
    "IC8H16O": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        128.214
    ],
    "C2H5OH": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        46.069
    ],
    "C2H5OO": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        61.0605
    ],
    "C2H5OOH": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        62.0684
    ],
    "C2H4O": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        44.0532
    ],
    "C6H5C2H": [
        2,
        534.3,
        5.71,
        0.77,
        0,
        1,
        102.136
    ],
    "BIPHENYL": [
        2,
        676.5,
        6.31,
        0,
        0,
        1,
        154.211
    ],
    "C14H10": [
        2,
        772,
        6.96,
        0,
        38.8,
        1,
        178.233
    ],
    "C6H5OH": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        94.113
    ],
    "FLUORENE": [
        2,
        712.6,
        6.89,
        0,
        0,
        1,
        166.222
    ],
    "C10H8": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        128.174
    ],
    "H": [
        0,
        145,
        2.05,
        0,
        0,
        0,
        1.00794
    ],
    "H2": [
        1,
        38,
        2.92,
        0,
        0.79,
        280,
        2.01588
    ],
    "H2O": [
        2,
        572.4,
        2.605,
        1.844,
        0,
        4,
        18.0153
    ],
    "H2O2": [
        2,
        107.4,
        3.458,
        0,
        0,
        3.8,
        34.0147
    ],
    "HCCO": [
        2,
        150,
        2.5,
        0,
        0,
        1,
        41.0293
    ],
    "HCO": [
        2,
        498,
        3.59,
        0,
        0,
        0,
        29.0183
    ],
    "HCO3": [
        2,
        498,
        3.59,
        0,
        0,
        0,
        61.0171
    ],
    "HE": [
        0,
        10.2,
        2.576,
        0,
        0,
        0,
        4.0026
    ],
    "HO2": [
        2,
        107.4,
        3.458,
        0,
        0,
        1,
        33.0067
    ],
    "IC4H8": [
        2,
        355,
        4.65,
        0,
        0,
        1,
        56.1075
    ],
    "IC3H7CHO": [
        2,
        455,
        4.65,
        0,
        0,
        1,
        72.1069
    ],
    "IC4H9P": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        57.1155
    ],
    "IC4H9P-OO": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "IC4H9T": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        57.1155
    ],
    "IC4H9T-OO": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "IC4H10": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        58.1234
    ],
    "IC16H34": [
        2,
        650,
        8.35,
        0,
        0,
        1,
        226.446
    ],
    "IC4H7": [
        2,
        355,
        4.65,
        0,
        0,
        1,
        55.0996
    ],
    "IC8H18": [
        2,
        494,
        6.17,
        0,
        0,
        1,
        114.231
    ],
    "INDENE": [
        2,
        588.6,
        5.96,
        0.65,
        0,
        1,
        116.163
    ],
    "IC3H7": [
        2,
        303.4,
        4.81,
        0,
        0,
        1,
        43.0886
    ],
    "IC3H7OH": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        60.0959
    ],
    "IC3H7OO": [
        2,
        468.3,
        4.76,
        0,
        0,
        1,
        75.0874
    ],
    "IC3-QOOH": [
        2,
        468.3,
        4.76,
        0,
        0,
        1,
        75.0874
    ],
    "IC3-OOQOOH": [
        2,
        468.3,
        4.76,
        0,
        0,
        1,
        107.086
    ],
    "IC5H10": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        70.1344
    ],
    "NEOC5-OQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        118.133
    ],
    "IC4-OQOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        104.106
    ],
    "C3-OQOOH": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        90.0788
    ],
    "NC4-OQOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        104.106
    ],
    "NC5-OQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        118.133
    ],
    "NC7-OQOOH": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        146.186
    ],
    "IC8-OQOOH": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        160.213
    ],
    "DME-OQOOH": [
        2,
        403.4,
        4.81,
        0,
        0,
        1,
        92.0514
    ],
    "NC10-OQOOH": [
        2,
        640.98,
        7.15,
        0,
        0,
        1,
        188.267
    ],
    "NC12-OQOOH": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        216.321
    ],
    "IC16-OQOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        272.428
    ],
    "MCYC6-OQOOH": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        144.17
    ],
    "MTBE-OQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        134.132
    ],
    "IC3H5CHO": [
        2,
        357,
        5.18,
        0,
        0,
        1,
        70.091
    ],
    "MCYC6": [
        2,
        495.3,
        5.68,
        0.43,
        12.3,
        1,
        98.1882
    ],
    "CH3CHO": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        44.0532
    ],
    "CH3CO3": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        75.044
    ],
    "C10H7CH3": [
        2,
        660,
        6.35,
        0,
        0,
        1,
        142.2
    ],
    "CH3OO": [
        2,
        417,
        3.69,
        1.7,
        0,
        2,
        47.0336
    ],
    "CH3OOH": [
        2,
        481.8,
        3.626,
        0,
        0,
        1,
        48.0416
    ],
    "MTBE": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        88.1497
    ],
    "N2": [
        1,
        97.53,
        3.621,
        0,
        1.76,
        4,
        28.0135
    ],
    "C10H7OH": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        144.173
    ],
    "C10H7CHO": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        156.184
    ],
    "CH3C10H6OH": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        158.2
    ],
    "CH3C10H6O": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        157.192
    ],
    "NC4H9P": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        57.1155
    ],
    "NC4H9S": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        57.1155
    ],
    "NC4H10": [
        2,
        352,
        5.24,
        0,
        0,
        1,
        58.1234
    ],
    "NC10H22": [
        2,
        540.98,
        7.15,
        0,
        0,
        1,
        142.285
    ],
    "NC12H26": [
        2,
        580,
        7.6,
        0,
        0,
        1,
        170.338
    ],
    "NC5H12": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        72.1503
    ],
    "NC7H16": [
        2,
        459.98,
        6.31,
        0,
        0,
        1,
        100.204
    ],
    "NEOC5H12": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        72.1503
    ],
    "NC3H7": [
        2,
        303.4,
        4.81,
        0,
        0,
        1,
        43.0886
    ],
    "NC3H7OO": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        75.0874
    ],
    "NC3-QOOH": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        75.0874
    ],
    "NC3-OOQOOH": [
        2,
        487.9,
        4.82,
        0,
        0,
        1,
        107.086
    ],
    "O": [
        0,
        80,
        2.75,
        0,
        0,
        0,
        15.9994
    ],
    "O2": [
        1,
        107.4,
        3.458,
        0,
        1.6,
        3.8,
        31.9988
    ],
    "OH": [
        1,
        80,
        2.75,
        0,
        0,
        0,
        17.0073
    ],
    "IC8H16": [
        2,
        494,
        6.17,
        0,
        0,
        1,
        112.215
    ],
    "NC5H10": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        70.1344
    ],
    "PC3H4": [
        1,
        252,
        4.76,
        0,
        0,
        1,
        40.0648
    ],
    "CH3CO3H": [
        2,
        443.2,
        4.12,
        0,
        0,
        1,
        76.052
    ],
    "HCO3H": [
        2,
        443.2,
        4.12,
        0,
        0,
        1,
        62.0251
    ],
    "C3H6O": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        58.08
    ],
    "C5H8": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        68.1185
    ],
    "C16H10": [
        2,
        834.9,
        7.24,
        0,
        45,
        1,
        202.255
    ],
    "NC10-QOOH": [
        2,
        640.98,
        7.15,
        0,
        0,
        1,
        173.276
    ],
    "NC12-QOOH": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        201.329
    ],
    "C2-QOOH": [
        2,
        470.6,
        4.41,
        0,
        0,
        1.5,
        61.0605
    ],
    "C2-OOQOOH": [
        2,
        470.6,
        4.41,
        0,
        0,
        1.5,
        93.0593
    ],
    "C2-OQOOH": [
        2,
        470.6,
        4.41,
        0,
        0,
        1.5,
        76.052
    ],
    "NC4-QOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "NC5-QOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        103.141
    ],
    "NC7-QOOH": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        131.195
    ],
    "DME-QOOH": [
        2,
        403.4,
        4.81,
        0,
        0,
        1,
        77.0599
    ],
    "IC16-QOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        257.437
    ],
    "IC16T-QOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        257.437
    ],
    "IC8-QOOH": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        145.222
    ],
    "IC4P-QOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "IC4T-QOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "MCYC6-QOOH": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        129.179
    ],
    "MTBE-QOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        119.141
    ],
    "NEOC5-QOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        103.141
    ],
    "IC8T-QOOH": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        145.222
    ],
    "MCYC6T-QOOH": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        129.179
    ],
    "NC10H21": [
        2,
        540.98,
        7.15,
        0,
        0,
        1,
        141.277
    ],
    "NC10H21-OO": [
        2,
        640.98,
        7.15,
        0,
        0,
        1,
        173.276
    ],
    "NC12H25": [
        2,
        580,
        7.6,
        0,
        0,
        1,
        169.331
    ],
    "NC12H25-OO": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        201.329
    ],
    "C2H4OH": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        45.0611
    ],
    "CH2CHO": [
        2,
        436,
        3.97,
        0,
        0,
        2,
        43.0452
    ],
    "CH3CHOH": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        45.0611
    ],
    "NC4H9-OO": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        89.1143
    ],
    "NC5H11": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        71.1423
    ],
    "NC5H12OO": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        103.141
    ],
    "NC7H15": [
        2,
        459.98,
        6.31,
        0,
        0,
        1,
        99.1961
    ],
    "NC7H15-OO": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        131.195
    ],
    "C12H7": [
        2,
        693.1,
        6.47,
        0,
        18,
        1,
        151.188
    ],
    "CH3COCH2": [
        2,
        424.6,
        4.82,
        0,
        0,
        1,
        57.0721
    ],
    "C2H4CHO": [
        2,
        424.6,
        4.82,
        0,
        0,
        1,
        57.0721
    ],
    "CYC6-OO": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        115.152
    ],
    "CYC6H11": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        83.1533
    ],
    "CYC6H9": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        81.1375
    ],
    "CYC5H5": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        65.0947
    ],
    "RDIPE": [
        2,
        432,
        6,
        0,
        0,
        1,
        101.169
    ],
    "CH3OCH2": [
        2,
        303.4,
        4.81,
        0,
        0,
        1,
        45.0611
    ],
    "DME-OO": [
        2,
        403.4,
        4.81,
        0,
        0,
        1,
        77.0599
    ],
    "C6H4C2H": [
        2,
        535.6,
        5.72,
        0.77,
        12,
        1,
        101.128
    ],
    "RBIPHENYL": [
        2,
        676.5,
        6.31,
        0,
        0,
        1,
        153.203
    ],
    "C14H9": [
        2,
        772,
        6.96,
        0,
        38.8,
        1,
        177.225
    ],
    "C10H7": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        127.166
    ],
    "IC16H33-OO": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        257.437
    ],
    "IC16H33": [
        2,
        650,
        8.35,
        0,
        0,
        1,
        225.438
    ],
    "IC8H17": [
        2,
        494,
        6.17,
        0,
        0,
        1,
        113.223
    ],
    "IC8H17-OO": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        145.222
    ],
    "INDENYL": [
        2,
        588.6,
        5.96,
        0,
        0,
        1,
        115.155
    ],
    "RMCYC6-OO": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        129.179
    ],
    "RMCYC6": [
        2,
        495.3,
        5.68,
        0.43,
        12.3,
        1,
        97.1802
    ],
    "C10H7CH2": [
        2,
        660,
        6.35,
        0,
        0,
        1,
        141.192
    ],
    "C10H6CH3": [
        2,
        660,
        6.35,
        0,
        0,
        1,
        141.192
    ],
    "C6H4CH3": [
        2,
        495.3,
        5.68,
        0,
        0,
        1,
        91.1326
    ],
    "RMTBE": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        87.1417
    ],
    "MTBE-OO": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        119.141
    ],
    "C10H7O": [
        2,
        630.4,
        6.18,
        0,
        0,
        1,
        143.165
    ],
    "NEOC5H11": [
        2,
        392,
        5.64,
        0,
        0,
        1,
        71.1423
    ],
    "NEOC5H11-OO": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        103.141
    ],
    "C16H9": [
        2,
        834.9,
        7.24,
        0,
        45,
        1,
        201.247
    ],
    "C6H5C2H2": [
        2,
        546.2,
        6,
        0,
        0,
        1,
        103.144
    ],
    "RXYLENE": [
        2,
        523.6,
        5.96,
        0,
        0,
        1,
        105.159
    ],
    "C6H5C2H3": [
        2,
        546.2,
        6,
        0.13,
        15,
        1,
        104.152
    ],
    "TAME": [
        2,
        432,
        6,
        0,
        0,
        1,
        102.177
    ],
    "TETRALIN": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        132.205
    ],
    "DECALIN": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        138.253
    ],
    "RDECALIN": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        137.245
    ],
    "C7H8": [
        2,
        495.3,
        5.68,
        0.43,
        12.3,
        1,
        92.1405
    ],
    "C2H3": [
        2,
        209,
        4.1,
        0,
        0,
        1,
        27.0458
    ],
    "XYLENE": [
        2,
        523.6,
        5.96,
        0,
        0,
        1,
        106.167
    ],
    "NC10-OOQOOH": [
        2,
        640.98,
        7.15,
        0,
        0,
        1,
        205.274
    ],
    "NC12-OOQOOH": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        233.328
    ],
    "NC4-OOQOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        121.113
    ],
    "NC5-OOQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        135.14
    ],
    "NC7-OOQOOH": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        163.194
    ],
    "DME-OOQOOH": [
        2,
        403.4,
        4.81,
        0,
        0,
        1,
        109.059
    ],
    "IC16-OOQOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        289.436
    ],
    "IC16T-OOQOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        289.436
    ],
    "IC8-OOQOOH": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        177.221
    ],
    "IC4P-OOQOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        121.113
    ],
    "IC4T-OOQOOH": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        121.113
    ],
    "MCYC6-OOQOOH": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        161.178
    ],
    "MTBE-OOQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        151.139
    ],
    "NEOC5-OOQOOH": [
        2,
        492,
        5.64,
        0,
        0,
        1,
        135.14
    ],
    "MCYC6T-OOQOOH": [
        2,
        595.3,
        5.68,
        0.43,
        12.3,
        1,
        161.178
    ],
    "NC16H34": [
        2,
        650,
        8.35,
        0,
        0,
        1,
        226.446
    ],
    "NC16H33": [
        2,
        650,
        8.35,
        0,
        0,
        1,
        225.438
    ],
    "NC16H33-OO": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        257.437
    ],
    "NC16-QOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        257.437
    ],
    "NC16-OOQOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        289.436
    ],
    "NC16-OQOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        272.428
    ],
    "CN": [
        1,
        75,
        3.856,
        0,
        0,
        1,
        26.0177
    ],
    "H2CN": [
        1,
        569,
        3.63,
        0,
        0,
        1,
        28.0336
    ],
    "H2NO": [
        2,
        116.7,
        3.492,
        0,
        0,
        1,
        32.022
    ],
    "HCN": [
        1,
        569,
        3.63,
        0,
        0,
        1,
        27.0257
    ],
    "HCNO": [
        2,
        232.4,
        3.828,
        0,
        0,
        1,
        43.0251
    ],
    "HOCN": [
        2,
        232.4,
        3.828,
        0,
        0,
        1,
        43.0251
    ],
    "HNCO": [
        2,
        232.4,
        3.828,
        0,
        0,
        1,
        43.0251
    ],
    "HNNO": [
        2,
        232.4,
        3.828,
        0,
        0,
        1,
        45.0208
    ],
    "HNO": [
        2,
        116.7,
        3.492,
        0,
        0,
        1,
        31.0141
    ],
    "N": [
        0,
        71.4,
        3.298,
        0,
        0,
        0,
        14.0067
    ],
    "N2H2": [
        2,
        71.4,
        3.798,
        0,
        0,
        1,
        30.0294
    ],
    "N2H3": [
        2,
        200,
        3.9,
        0,
        0,
        1,
        31.0373
    ],
    "N2H4": [
        2,
        205,
        4.23,
        0,
        4.26,
        1.5,
        32.0452
    ],
    "N2O": [
        1,
        232.4,
        3.828,
        0,
        0,
        1,
        44.0129
    ],
    "NCO": [
        1,
        232.4,
        3.828,
        0,
        0,
        1,
        42.0171
    ],
    "NH": [
        1,
        80,
        2.65,
        0,
        0,
        4,
        15.0147
    ],
    "NH2": [
        2,
        80,
        2.65,
        0,
        2.26,
        4,
        16.0226
    ],
    "NH3": [
        2,
        481,
        2.92,
        1.47,
        0,
        10,
        17.0306
    ],
    "NNH": [
        2,
        71.4,
        3.798,
        0,
        0,
        1,
        29.0214
    ],
    "NO": [
        1,
        97.5,
        3.621,
        0,
        1.76,
        4,
        30.0061
    ],
    "NO2": [
        2,
        200,
        3.5,
        0,
        0,
        1,
        46.0055
    ],
    "HONO": [
        2,
        200,
        3.5,
        0,
        0,
        1,
        47.0135
    ],
    "HNO2": [
        2,
        200,
        3.5,
        0,
        0,
        1,
        47.0135
    ],
    "NO3": [
        2,
        300,
        3.5,
        0,
        0,
        1,
        62.0049
    ],
    "HONO2": [
        2,
        300,
        3.5,
        0,
        0,
        1,
        63.0129
    ],
    "CH3CN": [
        1,
        500,
        4.63,
        0,
        0,
        1,
        41.0526
    ],
    "CH3NO2": [
        2,
        200,
        4.5,
        0,
        0,
        1,
        61.0404
    ],
    "CH3ONO": [
        2,
        200,
        4.5,
        0,
        0,
        1,
        61.0404
    ],
    "CH3NO": [
        1,
        97.5,
        3.621,
        0,
        1.76,
        4,
        45.041
    ],
    "CH3ONO2": [
        2,
        300,
        4.5,
        0,
        0,
        1,
        77.0398
    ],
    "CH2CN": [
        1,
        232.4,
        3.828,
        0,
        0,
        1,
        40.0446
    ],
    "BIN1A": [
        2,
        951.685,
        8.471,
        0,
        0,
        1,
        256.347
    ],
    "BIN1B": [
        2,
        951.685,
        8.471,
        0,
        0,
        1,
        250.299
    ],
    "CYC6-QOOH-2": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        115.152
    ],
    "CYC6-QOOH-3": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        115.152
    ],
    "CYC6-QOOH-4": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        115.152
    ],
    "CYC6-OOQOOH-2": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        147.151
    ],
    "CYC6-OOQOOH-3": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        147.151
    ],
    "CYC6-OOQOOH-4": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        147.151
    ],
    "CYC6-OQOOH-2": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        130.144
    ],
    "CYC6-OQOOH-3": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        130.144
    ],
    "CYC6-OQOOH-4": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        130.144
    ],
    "CYC6H10-O-12": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        98.1448
    ],
    "CYC6H10-O-13": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        98.1448
    ],
    "CYC6H10-O-14": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        98.1448
    ],
    "C3H5OOH": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        74.0794
    ],
    "C5EN-OQOOH-35": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        116.117
    ],
    "C5H8O": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        84.1179
    ],
    "NC5H9-3": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        69.1265
    ],
    "C3H5OO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        73.0715
    ],
    "C5EN-OO": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        101.125
    ],
    "C5EN-QOOH": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        101.125
    ],
    "C5EN-OOQOOH-35": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        133.124
    ],
    "NC3H7OH": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        60.0959
    ],
    "N1C4H9OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        74.1228
    ],
    "N2C4H9OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        74.1228
    ],
    "CH3CH2CHOHCH2": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CH2CHOCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CH2COHCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CHCHOHCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH2CH2CHOHCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "MEK": [
        2,
        454,
        5.413,
        3.3,
        0,
        1,
        72.1069
    ],
    "TC4H9OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        74.1228
    ],
    "IC4H9OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        74.1228
    ],
    "CH3CH2CH2CH2O": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "C3H7CHO": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        72.1069
    ],
    "CH3CH2CHOH": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        59.088
    ],
    "CH3CHCH2OH": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        59.088
    ],
    "CH2CH2CH2OH": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        59.088
    ],
    "CH3CH2CH2O": [
        2,
        482.146548,
        5.008549665,
        1.66,
        6.74,
        1,
        59.088
    ],
    "CH3COHCH3": [
        2,
        468.3,
        4.76,
        0,
        0,
        1,
        59.088
    ],
    "CH2CHOHCH3": [
        2,
        468.3,
        4.76,
        0,
        0,
        1,
        59.088
    ],
    "CH3CH2CH2CHOH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CH2CHCH2OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CHCH2CH2OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH2CH2CH2CH2OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "RTC4H8OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "RTC4H9O": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CHCH2OCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CHCH3CHOH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH3CCH2OHCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "CH2CHCH2OHCH3": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        73.1149
    ],
    "C4H7OH": [
        2,
        503.0722524,
        5.339941638,
        1.67,
        8.88,
        1,
        72.1069
    ],
    "C3H5OH": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        58.08
    ],
    "RCRESOLO": [
        2,
        621.1,
        5.64,
        0,
        0,
        1,
        107.132
    ],
    "RCRESOLC": [
        2,
        621.1,
        5.64,
        0,
        0,
        1,
        107.132
    ],
    "C10H10": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        130.189
    ],
    "BZFUR": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        118.135
    ],
    "ODECAL": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        138.253
    ],
    "RTETRALIN": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        131.197
    ],
    "RTETRAOO": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        163.196
    ],
    "TMBENZ": [
        2,
        523.6,
        5.96,
        0,
        0,
        1,
        120.194
    ],
    "NPBENZ": [
        2,
        495.3,
        5.68,
        0.43,
        12.3,
        1,
        120.194
    ],
    "RC9H11": [
        2,
        523.6,
        5.96,
        0,
        0,
        1,
        119.186
    ],
    "C6H5OCH3": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        108.14
    ],
    "MB": [
        2,
        468,
        5.85,
        0,
        0,
        0,
        102.133
    ],
    "RMBX": [
        2,
        468.5,
        5.23,
        0,
        0,
        1,
        101.125
    ],
    "MCROT": [
        2,
        468.5,
        5.23,
        0,
        0,
        1,
        100.117
    ],
    "MACRIL": [
        2,
        430.1,
        5.833,
        0,
        0,
        1,
        86.0904
    ],
    "RMP3": [
        2,
        430.1,
        5.833,
        0,
        0,
        1,
        87.0984
    ],
    "CH3OCO": [
        2,
        395,
        4.037,
        1.3,
        0,
        1,
        59.0446
    ],
    "ETMB583": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        116.117
    ],
    "KEHYMB": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        148.116
    ],
    "DIBZFUR": [
        2,
        676.5,
        6.31,
        0,
        0,
        1,
        168.195
    ],
    "DIFENET": [
        2,
        676.5,
        6.31,
        0,
        0,
        1,
        170.211
    ],
    "RMBOOX": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        133.124
    ],
    "QMBOOX": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        133.124
    ],
    "ZMBOOX": [
        2,
        508,
        5.2,
        0,
        0,
        1,
        165.123
    ],
    "KHDECA": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        184.235
    ],
    "QDECOOH": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        169.244
    ],
    "RDECOO": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        169.244
    ],
    "ZDECA": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        201.243
    ],
    "RMCROTA": [
        2,
        468.5,
        5.23,
        0,
        0,
        1,
        99.1094
    ],
    "MD": [
        2,
        604.4,
        7.305,
        1.7,
        0,
        1,
        186.294
    ],
    "RMDX": [
        2,
        604.4,
        7.305,
        1.7,
        0,
        1,
        185.287
    ],
    "CH3OCHO": [
        2,
        395,
        4.037,
        1.3,
        0,
        1,
        60.0526
    ],
    "ETEROMD": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        200.278
    ],
    "MDKETO": [
        2,
        680,
        7.6,
        0,
        0,
        1,
        232.277
    ],
    "C7H15COCHO": [
        2,
        594,
        6.17,
        0,
        0,
        1,
        156.225
    ],
    "RMDOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        217.285
    ],
    "QMDOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        217.285
    ],
    "ZMDOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        249.284
    ],
    "U2ME10": [
        2,
        604.4,
        7.305,
        2,
        0,
        1,
        182.263
    ],
    "UME10": [
        2,
        604.4,
        7.305,
        2,
        0,
        1,
        184.279
    ],
    "UME7": [
        2,
        556.82,
        6.41,
        1.7,
        16.14,
        1,
        142.198
    ],
    "C12H22": [
        2,
        580,
        7.6,
        0,
        0,
        1,
        166.307
    ],
    "DCYC5": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        136.237
    ],
    "UME16": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        268.44
    ],
    "ETEROMPA": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        284.439
    ],
    "MPA": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        270.456
    ],
    "KHMLIN1": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        338.444
    ],
    "MLIN1": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        292.462
    ],
    "MLINO": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        294.478
    ],
    "MEOLE": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        296.494
    ],
    "MSTEA": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        298.51
    ],
    "RUME7": [
        2,
        556.82,
        6.41,
        1.7,
        16.14,
        1,
        141.19
    ],
    "RME7": [
        2,
        556.82,
        6.41,
        1.7,
        16.14,
        1,
        143.206
    ],
    "RUME10": [
        2,
        604.4,
        7.305,
        2,
        0,
        1,
        183.271
    ],
    "RMPAX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        269.448
    ],
    "QMPAOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        301.447
    ],
    "RMPAOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        301.447
    ],
    "ZMPAOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        333.445
    ],
    "RMLIN1A": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        291.454
    ],
    "RMLIN1X": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        291.454
    ],
    "RMLIN1OOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        323.453
    ],
    "QMLIN1OOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        323.453
    ],
    "ZMLIN1OOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        355.452
    ],
    "RMLINA": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        293.47
    ],
    "RMLINX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        293.47
    ],
    "RMLINOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        325.469
    ],
    "QMLINOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        325.469
    ],
    "ZMLINOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        357.467
    ],
    "RMEOLEA": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        295.486
    ],
    "RMEOLES": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        295.486
    ],
    "RMEOLEOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        327.484
    ],
    "QMEOLEOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        327.484
    ],
    "ZMEOLEOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        359.483
    ],
    "RSTEAX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        297.502
    ],
    "RMSTEAOOX": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        329.5
    ],
    "QMSTEAOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        329.5
    ],
    "ZMSTEAOOH": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        361.499
    ],
    "U2ME12": [
        2,
        620,
        8,
        0,
        0,
        1,
        210.316
    ],
    "ALDEST": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        130.144
    ],
    "RALDEST": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        129.136
    ],
    "C12H18": [
        2,
        620,
        8,
        0,
        0,
        1,
        162.275
    ],
    "RODECA": [
        2,
        630.4,
        6.18,
        0,
        16.5,
        1,
        137.245
    ],
    "ALDINS": [
        2,
        620,
        8,
        0,
        0,
        1,
        192.301
    ],
    "RUME16": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        267.432
    ],
    "NC10H19": [
        2,
        540.98,
        7.15,
        0,
        0,
        1,
        139.261
    ],
    "C8H9": [
        2,
        546.2,
        6,
        0,
        0,
        1,
        105.159
    ],
    "NC7H13OOH": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        130.187
    ],
    "NC7H13": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        97.1802
    ],
    "LC6H5": [
        2,
        412.3,
        5.349,
        0,
        0,
        1,
        77.1057
    ],
    "C6H2": [
        1,
        357,
        5.18,
        0,
        0,
        1,
        74.0819
    ],
    "C8H2": [
        1,
        495.3,
        5.68,
        0.43,
        12.3,
        1,
        98.1039
    ],
    "C6H3": [
        1,
        357,
        5.18,
        0,
        0,
        1,
        75.0898
    ],
    "C6H4": [
        2,
        412.3,
        5.349,
        0,
        0,
        1,
        76.0978
    ],
    "BENZYNE": [
        2,
        468.5,
        5.23,
        0,
        10.3,
        1,
        76.0978
    ],
    "NC10MOOH": [
        2,
        640.98,
        7.15,
        0,
        0,
        1,
        172.268
    ],
    "MSTEAKETO": [
        2,
        750,
        8.35,
        0,
        0,
        1,
        344.492
    ],
    "C5H5O": [
        2,
        450,
        5.5,
        0,
        0,
        1,
        81.0941
    ],
    "C2H2O2": [
        2,
        470.6,
        4.41,
        0,
        0,
        1.5,
        58.0367
    ],
    "C2H4O2": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        60.0526
    ],
    "GLIET": [
        2,
        470.6,
        4.41,
        0,
        0,
        1.5,
        62.0684
    ],
    "C3H4O2": [
        2,
        435.2,
        4.662,
        2.7,
        0,
        1,
        72.0636
    ],
    "C3H4O3": [
        2,
        435.2,
        4.662,
        2.7,
        0,
        1,
        88.063
    ],
    "C3H6O2": [
        2,
        503.072,
        5.339,
        1.67,
        7.016,
        1,
        74.0794
    ],
    "C4H6O2": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        86.0904
    ],
    "C5H4O2": [
        2,
        524.69,
        5.653,
        0,
        0,
        1,
        96.0856
    ],
    "C5H8O4": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        132.116
    ],
    "C6H6O3": [
        2,
        567.841,
        5.915,
        0,
        0,
        1,
        126.112
    ],
    "C6H8O4": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        144.127
    ],
    "C6H10O5": [
        2,
        568.5,
        5.23,
        0,
        10.3,
        1,
        162.142
    ],
    "C8H10O3": [
        2,
        621.1,
        5.64,
        0,
        0,
        1,
        154.166
    ],
    "C9H10O2": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        150.177
    ],
    "C11H12O4": [
        2,
        663.45,
        6.362,
        0,
        0,
        1,
        208.214
    ],
    "C4H3O": [
        2,
        425.929,
        5.015,
        0,
        0,
        1,
        67.0672
    ],
    "HCOOH": [
        2,
        470.6,
        3.855,
        0,
        0,
        1,
        46.0257
    ],
    "ACETOL": [
        2,
        503.072,
        5.339,
        1.67,
        7.016,
        1,
        74.0794
    ],
    "GLYCEROL": [
        2,
        748.365,
        5.2,
        1.93,
        9.43,
        1,
        92.0947
    ],
    "CH2CCHCHO": [
        2,
        362.6,
        4.53,
        0,
        0,
        1.5,
        68.0752
    ],
    "KEHYBU1": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        120.105
    ],
    "RBU1OOX": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        105.114
    ],
    "QBU1OOX": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        105.114
    ],
    "ZBU1OOX": [
        2,
        496,
        5.2,
        0,
        0,
        1,
        137.112
    ],
    "DMF": [
        2,
        524.828,
        5.653,
        0,
        0,
        1,
        96.1289
    ],
    "DMF-3YL": [
        2,
        521.629,
        5.634,
        0,
        0,
        1,
        95.121
    ],
    "MEFU2": [
        2,
        478.946,
        5.364,
        0,
        0,
        1,
        82.102
    ],
    "C4H4O": [
        2,
        429.63,
        5.04,
        0,
        0,
        1,
        68.0752
    ],
    "ETC3H4O2": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        72.0636
    ],
    "KEA3B3": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        104.062
    ],
    "KEA3G2": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        104.062
    ],
    "RALD3G": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        57.0721
    ],
    "RALD3B": [
        2,
        411,
        4.82,
        0,
        0,
        1,
        57.0721
    ],
    "C3H5CHO": [
        2,
        357,
        5.18,
        0,
        0,
        1,
        70.091
    ],
    "C7DIONE": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        128.171
    ],
    "C7KETONE": [
        2,
        559.98,
        6.31,
        0,
        0,
        1,
        114.188
    ],
    "CH2OOHCHCHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        89.0709
    ],
    "CH2OOCH2CHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        89.0709
    ],
    "CH2CHOOHCHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        89.0709
    ],
    "CH3CHOOCHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        89.0709
    ],
    "CH2OOHCHOOCHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        121.07
    ],
    "CH2OOCHOOHCHO": [
        2,
        407.8,
        4.14,
        0,
        0,
        1,
        121.07
    ],
    "ERC4H8CHO": [
        2,
        408,
        5.2,
        0,
        0,
        1,
        85.1259
    ]
}

export default function TransportParameters() {
    let _transportDict = transportDict;

    function getGeometry(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][0];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getLJpotential(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][1];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getLJdiameter(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][2];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getDipole(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][3];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getPolar(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][4];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getCollision(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][5];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    function getMolecularWeight(gasSpecieName) {
        try {
            return _transportDict[gasSpecieName][6];
        } catch (error) {
            console.log(error);
            AsaliError("Unknwon species name: " + gasSpecieName)
        }
    }

    return {
        getGeometry,
        getLJpotential,
        getLJdiameter,
        getDipole,
        getPolar,
        getCollision,
        getMolecularWeight
    }
}